# Generated by roxygen2: do not edit by hand

S3method(plot,ar_greenreg)
S3method(plot,arima_greenreg)
S3method(plot,arma_greenreg)
S3method(plot,logistico_greenreg)
S3method(plot,ma_greenreg)
S3method(plot,poisson_greenreg)
S3method(plot,rlm_greenreg)
S3method(plot,rls_greenreg)
S3method(print,ar_greenreg)
S3method(print,arima_greenreg)
S3method(print,arma_greenreg)
S3method(print,logistico_greenreg)
S3method(print,ma_greenreg)
S3method(print,poisson_greenreg)
S3method(print,rlm_greenreg)
S3method(print,rls_greenreg)
export(analisis_datos)
export(logistico)
export(modelo_ar)
export(modelo_arima)
export(modelo_arma)
export(modelo_ma)
export(reg_poisson)
export(rlm)
export(rls)
import(ggplot2)
importFrom(ggrepel,geom_text_repel)
importFrom(lmtest,bptest)
importFrom(lmtest,dwtest)
importFrom(lmtest,raintest)
importFrom(stats,Box.test)
importFrom(stats,acf)
importFrom(stats,aggregate)
importFrom(stats,anova)
importFrom(stats,arima)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,cooks.distance)
importFrom(stats,cor)
importFrom(stats,density)
importFrom(stats,df.residual)
importFrom(stats,dnorm)
importFrom(stats,dpois)
importFrom(stats,filter)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,hatvalues)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,pacf)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,reorder)
importFrom(stats,resid)
importFrom(stats,residuals)
importFrom(stats,rstandard)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,step)
importFrom(utils,globalVariables)
importFrom(utils,menu)
